import os

import pandas as pd

from justclust.data.bolzano import cols, read_data, wcols
# from justclust.explore.algclusters import explore_models
from justclust.explore.preprocs import ApplyW, explore_preprocs, get_preprocs
from justclust.paths.bolzano import report_dir

# %%
# read and filter/select data
raw = read_data()

# save to a file:
# raw.to_file("raw.geojson", driver="GeoJSON")

# use selected columns
selected = raw.loc[:, cols].dropna()


# %%
# Explore clustering pre-processing
apply_weight = ApplyW(wcols)
preprocs = get_preprocs(selected, apply_weight)

os.makedirs(report_dir, exist_ok=True)

prescorefile = report_dir / "scores_preprocess.xlsx"
if prescorefile.exists():
    print(f"Reading pre-processed scores from: {prescorefile}")
    pre_scores = pd.read_excel(prescorefile)
else:
    print(
        f"Pre-processed file ({prescorefile}) not found, start computing the main metrics"
    )
    # weighted = selected * wcols
    apply_weight = ApplyW(wcols)
    pre_scores = explore_preprocs(selected)
    pre_scores.to_excel(prescorefile)

print("=" * 50)
print(f"BEST PRE-PROCESSING (10/{len(pre_scores)}):")
print(pre_scores.sort_values("hopkins", acending=False).loc[:10, :])
print("-" * 50)
print("Hopkins statistics of main pre-processing options")
print(pre_scores["hopkins"].describe())

# explore_models(
#     data: pd.DataFrame,
#     cldf: gpd.GeoDataFrame,
#     rdir: Path,
#     models: Dict[str, Dict[str, Any]] = None,
#     n_jobs: int=-1
# )
